# MiddleAuthClient

Currrently a set of decorators for helping flask apps interact with the middle-auth authentication service

define REDISHOST, and REDISPORT environment variables to use this package